import java.util.*;
import java.io.*;

public class WordixRus { 
    static class Word implements Comparable { 
        byte[] str;
        int    hash;
        int    count;
        
        public int hashCode() { 
            return hash;
        }
        
        public boolean equals(Object o) { 
            return compareTo(o) == 0;
        }
        
        public int compareTo(Object o) { 
            Word w = (Word)o;
            int n = str.length < w.str.length ? str.length : w.str.length;
            for (int i = 0; i < n; i++) { 
                int diff = str[i] - w.str[i];
                if (diff != 0) { 
                    return diff;
                }            
            }
            return str.length - w.str.length;
        }
        
        boolean startsWith(Word w) { 
            if (w.str.length > str.length) { 
                return false;
            }
            for (int i = 0; i < w.str.length; i++) { 
                if (w.str[i] != str[i]) { 
                    return false;
                }
            }
            return true;
        }
        
        Word(String s) { 
            str = s.getBytes();
            int h = 0;
            for (int i = 0; i < str.length; i++) { 
                h = h*31 + (str[i] & 0xFF);
            }
            hash = h;
            count = 0;
        }
        Word(byte[] buf, int from, int till) { 
            str = new byte[till-from];
            for (int i = 0; from < till; i++, from++) { 
                str[i] = (byte)(buf[from] & ~0x20);
            }
            int h = 0;
            for (int i = 0; i < str.length; i++) { 
                h = h*31 + (str[i] & 0xFF);
            }
            hash = h;
            count = 0;
        }
    };

    static final int FREQUENCY = 0;
    static final int MAX_LENGTH = 5;

    public static void main(String[] args) throws Exception {
	BufferedReader in = new BufferedReader(new FileReader("Zalizniak.win"));
	String line;
        int rc;
	TreeMap hash = new TreeMap();
      nextLine:
	while ((line = in.readLine()) != null) { 
	    int i = line.indexOf(' ');
	    if (i > 1 && i <= MAX_LENGTH) {
                int j = line.indexOf(' ', i+1);
                if (j > 0) { 
                    int k = line.indexOf(' ', ++j);
                    if (k > 0) { 
                        String type = line.substring(j, k);
                        if (type.equals("") || type.equals("") || type.equals("") || type.equals("") || type.equals(""))
                        {
                            String w = line.substring(0, i).toUpperCase();
                            Word word = new Word(w);                
                            hash.put(word, word);
                        }
                    }
                }
            }
        }
        if (FREQUENCY != 0) { 
            byte[] buf = new byte[1025*1024];
            FileInputStream fs = new FileInputStream("samples.rus");
            while ((rc = fs.read(buf)) > 0) { 
                for (int i = 1; i < rc; i++) { 
                    int j = i;
                    byte b = 0;
                    while (j < rc && (b = buf[j]) < 0) {
                        j += 1;
                    }
                    if (j > i+1 && buf[i-1] == ' ' && b == ' ') { 
                        Word w = new Word(buf, i, j);
                        Word w1 = (Word)hash.get(w);
                        if (w1 != null) { 
                            w1.count += 1;
                        }
                    }
                }
            }
            fs.close();
        }
	FileOutputStream out = new FileOutputStream("wordix-rus.dic");
	Iterator iterator = hash.values().iterator();
	int n = 0;
        int totalSize = 0;
        Word prevWord = null;
	while (iterator.hasNext()) { 
	    Word w = (Word)iterator.next();
            if (w.count >= FREQUENCY) { 
                if (prevWord == null || !w.startsWith(prevWord)) { 
                    prevWord = w;
                    out.write(w.str);
                    out.write('\n');
                    n += 1;
                    totalSize += 1 + w.str.length;
                }
	    }
	}
	out.close();
	System.out.println("Words " + n + ", size " + totalSize);
    }
}